%define _disable_ld_no_undefined %{nil}
%global _legacy_common_support 1

%global _hardened_build 1

%global with_nfsidmap 1


# Conditionally enable some FSALs, disable others.
#
# 1. rpmbuild accepts these options (gpfs as example):
#    --with gpfs
#    --without gpfs

%define on_off_switch() %%{?with_%1:ON}%%{!?with_%1:OFF}

# A few explanation about %%bcond_with and %%bcond_without
# /!\ be careful: this syntax can be quite messy
# %%bcond_with means you add a "--with" option, default = without this feature
# %%bcond_without adds a"--without" so the feature is enabled by default

%bcond_without nullfs
%global use_fsal_null %{on_off_switch nullfs}

%bcond_with gpfs
%global use_fsal_gpfs %{on_off_switch gpfs}

%bcond_with xfs
%global use_fsal_xfs %{on_off_switch xfs}

%bcond_with ceph
%global use_fsal_ceph %{on_off_switch ceph}

%bcond_with lustre
%global use_fsal_lustre %{on_off_switch lustre}

%bcond_with shook
%global use_fsal_shook %{on_off_switch shook}

# Disabled by default, as glusterfs was dropped in mga6 as unmaintained
%bcond_with gluster
%global use_fsal_gluster %{on_off_switch gluster}

%bcond_with hpss
%global use_fsal_hpss %{on_off_switch hpss}

%bcond_with panfs
%global use_fsal_panfs %{on_off_switch panfs}

%bcond_with pt
%global use_fsal_pt %{on_off_switch pt}

%bcond_with rdma
%global use_rdma %{on_off_switch rdma}

%bcond_without jemalloc

%bcond_with lustre_up
%global use_lustre_up %{on_off_switch lustre_up}

%bcond_with lttng
%global use_lttng %{on_off_switch lttng}

%bcond_without utils
%global use_utils %{on_off_switch utils}

%bcond_without gui_utils
%global use_gui_utils %{on_off_switch gui_utils}

%bcond_without system_ntirpc
%global use_system_ntirpc %{on_off_switch system_ntirpc}

%ifnarch %ix86 armv7hl
%bcond_without rados_recov
%else
%bcond_with rados_recov
%endif
%global use_rados_recov %{on_off_switch rados_recov}

%global dev_version %{lua: extraver = string.gsub('', '%-', '.'); print(extraver) }

Name:		nfs-ganesha
Version:	2.8.2
Release:	%mkrel 8
Summary:	NFS-Ganesha is a NFS Server running in user space
Group:		System/Servers
License:	LGPLv3+
Url:		https://github.com/nfs-ganesha/nfs-ganesha/wiki
Source0:	https://github.com/%{name}/%{name}/archive/V%{version}/%{name}-%{version}%{dev_version}.tar.gz
Patch1:		0001-src-scripts-gpfs-epoch.patch
Patch2:		nfs-ganesha-2.8.1-add-missing-include-in-CMakeLists.patch
Patch3:		0002-src-CMakeLists.txt.patch

BuildRequires:	cmake
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	pkgconfig(krb5)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(liburcu)
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(uuid)
%if %{with rados_recov} || %{with rados_urls}
BuildRequires:	librados-devel
%endif
BuildRequires:	wbclient-devel
%if %{with system_ntirpc}
BuildRequires:	pkgconfig(libntirpc) >= 1.8.0
%endif
Requires:	dbus
Requires:	nfs-utils
%if %{with_nfsidmap}
BuildRequires:	pkgconfig(libnfsidmap)
%else
BuildRequires:	nfs-utils-lib-devel
%endif
%if %{with rdma}
BuildRequires:	libmooshika-devel >= 0.6-0
%endif
%if %{with jemalloc}
BuildRequires:	pkgconfig(jemalloc)
%endif
%if %{with lustre_up}
BuildRequires:	lcap-devel >= 0.1-0
%endif

BuildRequires: systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# Use CMake variables

%description
nfs-ganesha : NFS-GANESHA is a NFS Server running in user space.
It comes with various back-end modules (called FSALs) provided as
shared objects to support different file systems and name-spaces.

%package mount-9P
Summary: a 9p mount helper
Group: System/Servers

%description mount-9P
This package contains the mount.9P script that clients can use
to simplify mounting to NFS-GANESHA. This is a 9p mount helper.

%package vfs
Summary: The NFS-GANESHA VFS FSAL
Group: System/Servers
BuildRequires: libattr-devel
Obsoletes: %{name}-xfs <= %{version}
Requires: nfs-ganesha = %{version}-%{release}

%description vfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support VFS based filesystems.

%package mem
Summary: The MEM-GANESHA MEM FSAL
Group: System/Servers
BuildRequires: libattr-devel
Requires: nfs-ganesha = %{version}-%{release}

%description mem
This package contains a FSAL shared object to
be used with NFS-Ganesha to support MEM.

%package proxy
Summary: The NFS-GANESHA PROXY FSAL
Group: System/Servers
BuildRequires: libattr-devel
Requires: nfs-ganesha = %{version}-%{release}

%description proxy
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PROXY based filesystems.

%if %{with utils}
%package utils
Summary: The NFS-GANESHA util scripts
Group: System/Servers
Requires:	python3-dbus, python3-gobject3, python3-pyparsing
%if %{with gui_utils}
BuildRequires:	python3-qt5-devel
Requires:	python3-qt5
%endif
BuildRequires:	pkgconfig(python3)
Requires: nfs-ganesha = %{version}-%{release}
Requires: python3

%description utils
This package contains utility scripts for managing the NFS-GANESHA server.
%endif

%if %{with lttng}
%package lttng
Summary: The NFS-GANESHA library for use with LTTng
Group: System/Servers
BuildRequires: pkgconfig(lttng-ust) >= 2.3
Requires: nfs-ganesha = %{version}-%{release}, lttng-tools >= 2.3,  lttng-ust >= 2.3

%description lttng
This package contains the libganesha_trace.so library. When preloaded
to the ganesha.nfsd server, it makes it possible to trace using LTTng.
%endif

%if %{with rados_recov}
%package rados-grace
Summary: The NFS-GANESHA command for managing the RADOS grace database
Group: System/Servers
Requires: nfs-ganesha = %{version}-%{release}

%description rados-grace
This package contains the ganesha-rados-grace tool for interacting with the
database used by the rados_cluster recovery backend and the
libganesha_rados_grace shared library for using RADOS storage for
recovery state.
%endif

# Option packages start here. use "rpmbuild --with lustre" (or equivalent)
# for activating this part of the spec file

# NULL
%if %{with nullfs}
%package nullfs
Summary: The NFS-GANESHA NULLFS Stackable FSAL
Group: System/Servers
Requires: nfs-ganesha = %{version}-%{release}

%description nullfs
This package contains a Stackable FSAL shared object to
be used with NFS-Ganesha. This is mostly a template for future (more sophisticated)
stackable FSALs.
%endif

# GPFS
%if %{with gpfs}
%package gpfs
Summary: The NFS-GANESHA GPFS FSAL
Group: System/Servers
Requires: nfs-ganesha = %{version}-%{release}

%description gpfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support GPFS backend.
%endif

# CEPH
%if %{with ceph}
%package ceph
Summary: The NFS-GANESHA CEPH FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	ceph >= 1:10.2.0
BuildRequires:	libcephfs1-devel >= 1:10.2.0

%description ceph
This package contains a FSAL shared object to
be used with NFS-Ganesha to support CEPH.
%endif

# LUSTRE
%if %{with lustre}
%package lustre
Summary: The NFS-GANESHA LUSTRE FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	lustre
BuildRequires:	libattr-devel
BuildRequires:	lustre

%description lustre
This package contains a FSAL shared object to
be used with NFS-Ganesha to support LUSTRE.
%endif

# SHOOK
%if %{with shook}
%package shook
Summary: The NFS-GANESHA LUSTRE/SHOOK FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	lustre shook-client
BuildRequires:	libattr-devel
BuildRequires:	lustre
BuildRequires:	shook-devel

%description shook
This package contains a FSAL shared object to
be used with NFS-Ganesha to support LUSTRE via SHOOK.
%endif

# XFS
%if %{with xfs}
%package xfs
Summary: The NFS-GANESHA XFS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
BuildRequires:	libattr-devel
BuildRequires:	xfsprogs-devel

%description xfs
This package contains a shared object to be used with FSAL_VFS
to support XFS correctly.
%endif

# HPSS
%if %{with hpss}
%package hpss
Summary: The NFS-GANESHA HPSS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
#BuildRequires:	hpssfs

%description hpss
This package contains a FSAL shared object to
be used with NFS-Ganesha to support HPSS.
%endif

# PANFS
%if %{with panfs}
%package panfs
Summary: The NFS-GANESHA PANFS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}

%description panfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PANFS.
%endif

# PT
%if %{with pt}
%package pt
Summary: The NFS-GANESHA PT FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}


%description pt
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PT.
%endif

# GLUSTER
%if %{with gluster}
%package gluster
Summary: The NFS-GANESHA GLUSTER FSAL
Group: System/Servers
Requires:	      nfs-ganesha = %{version}-%{release}
BuildRequires:        pkgconfig(glusterfs-api) >= 3.7.9
#For missing requires in glusterfs-api devel pkg
BuildRequires:        glusterfs-api
BuildRequires:        libattr-devel
BuildRequires:        libacl-devel

%description gluster
This package contains a FSAL shared object to
be used with NFS-Ganesha to support Gluster.
%endif

%prep
%setup -q -n %{name}-%{version}%{dev_version}
rm -rf contrib/libzfswrapper
%autopatch -p1

%build
%global _vpath_srcdir src
%cmake							\
	-DBUILD_CONFIG=rpmbuild				\
	-DUSE_FSAL_NULL=%{use_fsal_null}		\
	-DUSE_FSAL_ZFS=OFF				\
	-DUSE_FSAL_XFS=%{use_fsal_xfs}			\
	-DUSE_FSAL_LUSTRE=%{use_fsal_lustre}		\
	-DUSE_FSAL_CEPH=%{use_fsal_ceph}		\
	-DUSE_FSAL_SHOOK=%{use_fsal_shook}		\
	-DUSE_FSAL_GPFS=%{use_fsal_gpfs}		\
	-DUSE_FSAL_HPSS=%{use_fsal_hpss}		\
	-DUSE_FSAL_PANFS=%{use_fsal_panfs}		\
	-DUSE_FSAL_PT=%{use_fsal_pt}			\
	-DUSE_FSAL_GLUSTER=%{use_fsal_gluster}		\
	-DUSE_SYSTEM_NTIRPC=%{use_system_ntirpc}	\
	-DUSE_9P_RDMA=%{use_rdma}			\
	-DUSE_FSAL_LUSTRE_UP=%{use_lustre_up}		\
	-DUSE_LTTNG=%{use_lttng}			\
	-DUSE_ADMIN_TOOLS=%{use_utils}			\
	-DUSE_GUI_ADMIN_TOOLS=%{use_gui_utils}		\
	-DUSE_RADOS_RECOV=%{use_rados_recov}		\
	-DUSE_FSAL_VFS=ON				\
	-DUSE_FSAL_PROXY=ON				\
	-DUSE_DBUS=ON					\
	-DUSE_9P=ON					\
	-DDISTNAME_HAS_GIT_DATA=OFF			\
%if %{with jemalloc}
	-DALLOCATOR=jemalloc
%endif

%cmake_build

%install
mkdir -p %{buildroot}%{_sysconfdir}/ganesha/
mkdir -p %{buildroot}%{_sysconfdir}/dbus-1/system.d
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/ganesha
mkdir -p %{buildroot}%{_localstatedir}/run/ganesha
pushd src
install -m 644 config_samples/logrotate_ganesha	%{buildroot}%{_sysconfdir}/logrotate.d/ganesha
install -m 644 scripts/ganeshactl/org.ganesha.nfsd.conf	%{buildroot}%{_sysconfdir}/dbus-1/system.d
install -m 755 tools/mount.9P	%{buildroot}%{_sbindir}/mount.9P

install -m 644 config_samples/vfs.conf %{buildroot}%{_sysconfdir}/ganesha

mkdir -p %{buildroot}%{_unitdir}
install -m 644 scripts/systemd/nfs-ganesha.service.el7	%{buildroot}%{_unitdir}/nfs-ganesha.service
install -m 644 scripts/systemd/nfs-ganesha-lock.service.el7	%{buildroot}%{_unitdir}/nfs-ganesha-lock.service
install -m 644 scripts/systemd/sysconfig/nfs-ganesha	%{buildroot}%{_sysconfdir}/sysconfig/ganesha

%if %{with pt}
install -m 644 config_samples/pt.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with xfs}
install -m 644 config_samples/xfs.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with ceph}
install -m 644 config_samples/ceph.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with lustre}
install -m 755 config_samples/lustre.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with gluster}
install -m 644 config_samples/logrotate_fsal_gluster %{buildroot}%{_sysconfdir}/logrotate.d/ganesha-gfapi
%endif

%if %{with gpfs}
install -m 644 config_samples/gpfs.conf	%{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.nfsd.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.main.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.log.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.exports.conf	%{buildroot}%{_sysconfdir}/ganesha
%endif

# setuptools >= 60 changes the environment to use its bundled copy of distutils
# by default, not the Python-bundled one. To run the Python's standard library
# distutils, the environment variable must be set.
# Although technically setuptools is not needed for the cmake scripts, if it's
# pulled by another package, it changes the environment and consequently,
# the build fails. This was reported in:
# https://github.com/pypa/setuptools/issues/3143
export SETUPTOOLS_USE_DISTUTILS=stdlib
cd ..
%cmake_install
cd -

install -m 644 ChangeLog %{buildroot}%{_defaultdocdir}/ganesha

# remove unwanted devel files
rm -f %{buildroot}%{_libdir}/libganesha_nfsd.so

# Fix shebang
sed -i 's@#!/usr/bin/python@#!/usr/bin/python3@' %{buildroot}%_bindir/{grace_period,manage_exports,ganesha_conf,ganesha_stats,get_clientids,export_stats_9pOps,ganesha_mgr,fake_recall,ganeshactl,ganesha-admin,manage_logger,client_stats_9pOps,manage_clients}

%post
%systemd_post nfs-ganesha
%systemd_post nfs-ganesha-lock

%preun
%systemd_preun nfs-ganesha-lock

%postun
%systemd_postun_with_restart nfs-ganesha-lock


%files
%license src/LICENSE.txt
%{_bindir}/ganesha.nfsd
%if ! %{with system_ntirpc}
%{_libdir}/libntirpc.so.1.3.0
%{_libdir}/libntirpc.so.1.3
%{_libdir}/libntirpc.so
%{_libdir}/pkgconfig/libntirpc.pc
%{_includedir}/ntirpc/
%endif
%{_libdir}/libganesha_nfsd.so.*
%dir %{_libdir}/ganesha/
%config %{_sysconfdir}/dbus-1/system.d/org.ganesha.nfsd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/ganesha
%config(noreplace) %{_sysconfdir}/logrotate.d/ganesha
%dir %{_sysconfdir}/ganesha/
%config(noreplace) %{_sysconfdir}/ganesha/ganesha.conf
%dir %{_defaultdocdir}/ganesha/
%{_defaultdocdir}/ganesha/*
%{_mandir}/man8/ganesha_conf.8*

%{_unitdir}/nfs-ganesha.service
%{_unitdir}/nfs-ganesha-lock.service

%if %{with rados_recov}
%files rados-grace
%{_bindir}/ganesha-rados-grace
#%%{_libdir}/libganesha_rados_recov.so*
%endif

%files mount-9P
%{_sbindir}/mount.9P

%files vfs
%{_libdir}/ganesha/libfsalvfs*
%config(noreplace) %{_sysconfdir}/ganesha/vfs.conf

%files proxy
%{_libdir}/ganesha/libfsalproxy*

%files mem
%{_libdir}/ganesha/libfsalmem*

# Optional packages
%if %{with nullfs}
%files nullfs
%{_libdir}/ganesha/libfsalnull*
%endif

%if %{with gpfs}
%files gpfs
%{_libdir}/ganesha/libfsalgpfs*
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.nfsd.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.main.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.log.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.exports.conf
%if ! %{with_systemd}
%{_sysconfdir}/init.d/nfs-ganesha-gpfs
%endif
%endif

%if %{with xfs}
%files xfs
%{_libdir}/ganesha/libfsalxfs*
%config(noreplace) %{_sysconfdir}/ganesha/xfs.conf
%endif

%if %{with ceph}
%files ceph
%{_libdir}/ganesha/libfsalceph*
%config(noreplace) %{_sysconfdir}/ganesha/ceph.conf
%endif

%if %{with lustre}
%files lustre
%config(noreplace) %{_sysconfdir}/ganesha/lustre.conf
%{_libdir}/ganesha/libfsallustre*
%endif

%if %{with shook}
%files shook
%{_libdir}/ganesha/libfsalshook*
%endif

%if %{with gluster}
%files gluster
%config(noreplace) %{_sysconfdir}/logrotate.d/ganesha-gfapi
%{_libdir}/ganesha/libfsalgluster*
%endif

%if %{with hpss}
%files hpss
%{_libdir}/ganesha/libfsalhpss*
%endif

%if %{with panfs}
%files panfs
%{_libdir}/ganesha/libfsalpanfs*
%endif

%if %{with pt}
%files pt
%{_libdir}/ganesha/libfsalpt*
%config(noreplace) %{_sysconfdir}/ganesha/pt.conf
%endif

%if %{with lttng}
%files lttng
%{_libdir}/ganesha/libganesha_trace*
%endif

%if %{with utils}
%files utils
%{python3_sitelib}/Ganesha/
%{python3_sitelib}/ganeshactl-*-info
%if %{with gui_utils}
%{_bindir}/ganesha-admin
%{_bindir}/ganesha_conf
%{_bindir}/manage_clients
%{_bindir}/manage_exports
%{_bindir}/manage_logger
%{_bindir}/ganeshactl
%{_bindir}/client_stats_9pOps
%{_bindir}/export_stats_9pOps
%endif
%{_bindir}/fake_recall
%{_bindir}/get_clientids
%{_bindir}/grace_period
%{_bindir}/ganesha_stats
%{_bindir}/sm_notify.ganesha
%{_bindir}/ganesha_mgr
%endif



%changelog
* Sun Nov 20 2022 daviddavid <daviddavid> 2.8.2-8.mga9
+ Revision: 1909168
- do not BR setuptools, use Python's bundled distutils
- rebuild for new libs

* Wed Apr 06 2022 umeabot <umeabot> 2.8.2-7.mga9
+ Revision: 1845945
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 2.8.2-6.mga9
+ Revision: 1786828
- rebuild for python-3.10

* Wed Dec 01 2021 wally <wally> 2.8.2-5.mga9
+ Revision: 1760448
- rebuild for userspace-rcu 0.13.0

* Sun Mar 28 2021 daviddavid <daviddavid> 2.8.2-4.mga9
+ Revision: 1711443
- rebuild for python 3.9

* Mon Dec 28 2020 luigiwalser <luigiwalser> 2.8.2-3.mga8
+ Revision: 1664643
- add rados-grace subpackage
+ tv <tv>
- Fix shebang
- disable XFS
- use -fcommon
- fix rados deps
- explicitely disable rados on 32bit
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Oct 16 2019 daviddavid <daviddavid> 2.8.2-1.mga8
+ Revision: 1454014
- new version: 2.8.2
- port to Python3 + PyQt5

* Wed Jul 17 2019 daviddavid <daviddavid> 2.8.1-1.mga8
+ Revision: 1422098
- add patch to fix missing include in CMakeLists
- new version: 2.8.1

* Tue Oct 09 2018 daviddavid <daviddavid> 2.6.2-2.mga7
+ Revision: 1318899
- disable ceph support
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri May 11 2018 kekepower <kekepower> 2.6.2-1.mga7
+ Revision: 1228236
- Update to version 2.6.2

* Fri Apr 13 2018 daviddavid <daviddavid> 2.6.1-2.mga7
+ Revision: 1218367
- rebuild for new libntirpc 1.6.2

* Fri Mar 30 2018 kekepower <kekepower> 2.6.1-1.mga7
+ Revision: 1213642
- Update to version 2.6.1

* Tue Mar 13 2018 kekepower <kekepower> 2.6.0-1.mga7
+ Revision: 1208800
- Added BR for python3-qt4-core
- Added new package, mem
- Fixed filenames for the systemd files
- Add BR for wbclient-devel
- Update to version 2.6.0

* Wed May 03 2017 akien <akien> 2.4.1-3.mga6
+ Revision: 1098907
- Disable gluster module, as glusterfs is being dropped

* Sun Jan 08 2017 daviddavid <daviddavid> 2.4.1-2.mga6
+ Revision: 1080601
- reenable gluster support
- enable ceph support (but not on armv5tl)
- add patch to find properly glusterfs-api

* Fri Dec 16 2016 neoclust <neoclust> 2.4.1-1.mga6
+ Revision: 1075548
- New version 2.4.1
- Rebuild against newer libntirpc
+ akien <akien>
- rebuild with new libntirpc

* Fri Feb 26 2016 spuhler <spuhler> 2.3.0-5.mga6
+ Revision: 979714
- rebuild with new libntirpc
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Nov 19 2015 daviddavid <daviddavid> 2.3.0-3.mga6
+ Revision: 904208
- rebuild for new jemalloc 4.0.4

* Fri Nov 06 2015 spuhler <spuhler> 2.3.0-2.mga6
+ Revision: 898300
- fixed Requires: python-gobject

* Fri Oct 30 2015 spuhler <spuhler> 2.3.0-1.mga6
+ Revision: 896804
- removed %%dir %%{_localstatedir}/run/ganesha
  * we don't need it
- fixed BuildRequires: pkgconfig(libntirpc)
- cleanup spec
- upgrade src to rel version (from RC7)
- imported package nfs-ganesha


* Mon Oct 19 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.11rc7
- 2.3.0 RC7

* Mon Oct 12 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.10rc6
- 2.3.0 RC6

* Thu Oct 8 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.9rc5
- 2.3.0 RC5 w/ CMakeLists.txt.patch and config-h.in.cmake.patch

* Wed Oct 7 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.8rc5
- 2.3.0 RC5 mount-9p w/o Requires: nfs-ganesha

* Tue Oct 6 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.7rc5
- 2.3.0 RC5 revised scripts/ganeshactl/CMakeLists.txt.patch

* Mon Oct 5 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.6rc5
- 2.3.0 RC5

* Mon Sep 28 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.5rc4
- 2.3.0 RC4

* Fri Sep 18 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.4rc3
- 2.3.0 RC3

* Fri Sep 11 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.3rc2
- 2.3.0 RC2

* Fri Sep 11 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.2rc1
- 2.3.0 RC1, revised .../SAL/nfs4_state_id.c.patch

* Wed Sep 9 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.3.0-0.1rc1
- 2.3.0 RC1

* Sat Aug 29 2015 Niels de Vos <ndevos@redhat.com> 2.2.0-6
- Rebuilt for jemalloc SONAME bump

* Fri Jul 17 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-5
- BuildRequires: libntirprc on base

* Fri Jul 17 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-4
- link with unbundled, shared libntirpc

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 27 2015 Niels de Vos <ndevos@redhat.com>
- improve readability and allow "rpmbuild --with .." options again

* Fri May 15 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-2
- %%license, build with glusterfs-3.7.0 GA

* Tue Apr 21 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-1
- 2.2.0 GA

* Mon Apr 20 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.13rc-final
- 2.2.0-0.13rc-final

* Mon Apr 13 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.12rc8
- 2.2.0-0.12rc8

* Mon Apr 6 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.11rc7
- 2.2.0-0.11rc7

* Thu Apr 2 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.10rc6
- 2.2.0-0.10rc6, with unbundled libntirpc

* Mon Mar 30 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.9rc6
- 2.2.0-0.9rc6

* Sun Mar 22 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.8rc5
- 2.2.0-0.8rc5

* Tue Mar 17 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.7rc4
- ntirpc-1.2.1.tar.gz

* Tue Mar 17 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.6rc4
- updated ntirpc-1.2.0.tar.gz

* Sun Mar 15 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.5rc4
- 2.2.0-0.5rc4

* Mon Feb 23 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.4rc3
- 2.2.0-0.4rc3

* Mon Feb 16 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.3rc2
- subpackage Requires: nfs-ganesha = %%{version}-%%{release}

* Mon Feb 16 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.2rc2
- 2.2.0-0.2rc2

* Fri Feb 13 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.2.0-0.1rc1
- 2.2.0-0.1rc1
- nfs-ganesha.spec based on upstream

* Thu Feb 12 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-14
- Fedora 23/rawhide build fixes
- Ceph restored in EPEL

* Mon Jan 19 2015 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-13
- Ceph retired from EPEL 7

* Thu Nov 6 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-12
- rebuild after libnfsidmap symbol version revert

* Wed Oct 29 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-11
- PyQt -> PyQt4 typo

* Mon Oct 27 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-10
- use upstream init.d script

* Thu Oct 2 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-9
- restore exclusion of gluster gfapi on rhel

* Thu Oct 2 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-8
- install /etc/dbus-1/system.d/org.ganesha.nfsd.conf
- build and install admin tools

* Mon Sep 29 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-7
- install /etc/sysconfig/nfs-ganesha file

* Fri Aug 29 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com>
- Ceph FSAL typo, #1135437

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 24 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-5
- use upstream nfs-ganesha.service

* Fri Jul 11 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-4
- keep fsal .so files, implementation now uses them

* Tue Jul 1 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-3
- static libuid2grp

* Tue Jul 1 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-2
- add libuid2grp.so

* Mon Jun 30 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.1.0-1
- nfs-ganesha-2.1.0 GA

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jun 2 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-9
- Ceph FSAL enabled with ceph-0.80

* Wed May 21 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-8
- getdents()->getdents64(), struct dirent -> struct dirent64

* Sat May 10 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com>
- and exclude libfsalceph

* Sat May 10 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com>
- exclude libfsalgluster correctly

* Fri May 9 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-7
- Ceph FSAL, in a subpackage, (but requires ceph >= 0.78)

* Mon Mar 31 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com>
- GlusterFS FSAL in a subpackage
- EPEL7 has jemalloc as of 2014-02-25

* Tue Jan 21 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com>
- sussed out github archive so as to allow correct Source0

* Fri Jan 17 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-6
- EPEL7 and xfsprogs

* Fri Jan 17 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-5
- EPEL7

* Mon Jan 6 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-4
- with glusterfs-api(-devel) >= 3.4.2

* Sat Jan 4 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-3
- with glusterfs-api

* Thu Jan 2 2014 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-2
- Build on RHEL6. Add sample init.d script

* Wed Dec 11 2013 Jim Lieb <lieb@sea-troll.net> - 2.0.0-1
- Update to V2.0.0 release

* Mon Nov 25 2013 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-0.2.rcfinal
- update to RC-final

* Fri Nov 22 2013 Kaleb S. KEITHLEY <kkeithle at redhat.com> 2.0.0-0.1.rc5
- Initial commit
